@@ -19,7 +19,7 @@ import argparse
 from easydict import EasyDict as edict
 import os
 from ..paint3d.DifferentiableRenderer.mesh_utils import convert_obj_to_glb
-
+from pathlib import Path
 
 class TrellisImageTo3DPipeline(Pipeline):
     """
@@ -63,18 +63,21 @@ class TrellisImageTo3DPipeline(Pipeline):
 
         shape_pipeline = Tri3DDiTFlowMatchingPipeline.from_pretrained(path)
 
+        current_dir = Path(__file__).resolve().parent
+        cus_pip = current_dir.parent / "paint3d" / "tripaintpbr"
+
         # paint model
         max_num_view = 6
         resolution = 768
         conf = Tri3DPaintConfig(max_num_view, resolution)
         conf.realesrgan_ckpt_path = os.path.join(path, "ckpt/RealESRGAN_x4plus.pth")
-        conf.multiview_cfg_path = "trellis_v3/paint3d/cfgs/hunyuan-paint-pbr.yaml"
-        conf.custom_pipeline = "trellis_v3/paint3d/tripaintpbr"
+        conf.multiview_cfg_path = os.path.join(path, "texture/paint.yaml")
+        conf.custom_pipeline = str(cus_pip)
         conf.multiview_pretrained_path = path
         conf.dino_ckpt_path =  os.path.join(path, "dinov2-giant")
         conf.model_path = path
         paint_pipeline = Tri3DPaintPipeline(conf)
-
+        
         models = {}
         pipeline = TrellisImageTo3DPipeline(
             models=None,
@@ -183,10 +186,10 @@ class TrellisImageTo3DPipeline(Pipeline):
         
         mesh_untextured = self.shape_pipeline(image=image)[0]
 
-        output_mesh_path = self.paint_pipeline(
+        output_mesh = self.paint_pipeline(
             mesh_path = mesh_untextured,
             image_path = image,
             output_mesh_path = None
         )
         
-        return mesh_untextured
\ No newline at end of file
+        return output_mesh
\ No newline at end of file
